# Generated by roxygen2: do not edit by hand

S3method("[",shard_buffer)
S3method("[",shard_descriptor)
S3method("[",shard_descriptor_lazy)
S3method("[",shard_results_placeholder)
S3method("[<-",shard_buffer)
S3method("[<-",shard_shared_vector)
S3method("[[",shard_descriptor)
S3method("[[",shard_descriptor_lazy)
S3method("[[",shard_results_placeholder)
S3method("[[<-",shard_shared_vector)
S3method("attr<-",shard_shared_vector)
S3method("attributes<-",shard_shared_vector)
S3method("dim<-",shard_shared_vector)
S3method("dimnames<-",shard_shared_vector)
S3method("names<-",shard_shared_vector)
S3method(as.array,shard_buffer)
S3method(as.double,shard_buffer)
S3method(as.integer,shard_buffer)
S3method(as.logical,shard_buffer)
S3method(as.matrix,shard_buffer)
S3method(as.raw,shard_buffer)
S3method(as.vector,shard_buffer)
S3method(as_tibble,shard_dataset)
S3method(as_tibble,shard_row_groups)
S3method(as_tibble,shard_table_buffer)
S3method(as_tibble,shard_table_handle)
S3method(close,shard_deep_shared)
S3method(close,shard_shared)
S3method(close,shard_shared_vector)
S3method(collect,shard_dataset)
S3method(collect,shard_row_groups)
S3method(collect,shard_table_handle)
S3method(dim,shard_buffer)
S3method(fetch,default)
S3method(fetch,shard_deep_shared)
S3method(fetch,shard_shared)
S3method(length,shard_buffer)
S3method(length,shard_descriptor)
S3method(length,shard_descriptor_lazy)
S3method(length,shard_results_placeholder)
S3method(materialize,default)
S3method(materialize,shard_shared)
S3method(materialize,shard_view_block)
S3method(materialize,shard_view_gather)
S3method(print,arena_result)
S3method(print,shard_apply_policy)
S3method(print,shard_buffer)
S3method(print,shard_deep_shared)
S3method(print,shard_descriptor)
S3method(print,shard_descriptor_lazy)
S3method(print,shard_dispatch_result)
S3method(print,shard_health_report)
S3method(print,shard_idx_range)
S3method(print,shard_pool)
S3method(print,shard_queue)
S3method(print,shard_reduce_result)
S3method(print,shard_report)
S3method(print,shard_result)
S3method(print,shard_results_placeholder)
S3method(print,shard_segment)
S3method(print,shard_shared)
S3method(print,shard_shared_vector)
S3method(print,shard_tiles)
S3method(print,shard_view_block)
S3method(print,shard_view_gather)
S3method(print,shard_worker)
S3method(shard_share_hook,default)
S3method(stream_map,shard_dataset)
S3method(stream_map,shard_row_groups)
S3method(stream_reduce,shard_dataset)
S3method(stream_reduce,shard_row_groups)
S3method(table_finalize,shard_table_buffer)
S3method(table_finalize,shard_table_sink)
S3method(table_write,shard_table_buffer)
S3method(table_write,shard_table_sink)
export(affinity_supported)
export(arena)
export(arena_depth)
export(as_shared)
export(as_tibble)
export(available_backings)
export(bool)
export(buffer)
export(buffer_advise)
export(buffer_close)
export(buffer_diagnostics)
export(buffer_info)
export(buffer_open)
export(buffer_path)
export(collect)
export(copy_report)
export(cow_report)
export(dispatch_chunks)
export(factor_col)
export(fetch)
export(float64)
export(idx_range)
export(in_arena)
export(int32)
export(is_block_view)
export(is_shared)
export(is_shared_vector)
export(is_view)
export(is_windows)
export(iterate_row_groups)
export(list_kernels)
export(materialize)
export(mem_report)
export(pin_workers)
export(pool_create)
export(pool_dispatch)
export(pool_get)
export(pool_health_check)
export(pool_lapply)
export(pool_sapply)
export(pool_status)
export(pool_stop)
export(raw_col)
export(recommendations)
export(register_kernel)
export(report)
export(results)
export(row_layout)
export(schema)
export(scratch_diagnostics)
export(scratch_matrix)
export(scratch_pool_config)
export(segment_advise)
export(segment_close)
export(segment_create)
export(segment_info)
export(segment_open)
export(segment_path)
export(segment_protect)
export(segment_read)
export(segment_report)
export(segment_size)
export(segment_write)
export(set_affinity)
export(shard_apply_matrix)
export(shard_apply_policy)
export(shard_crossprod)
export(shard_get_adapter)
export(shard_lapply_shared)
export(shard_list_adapters)
export(shard_map)
export(shard_reduce)
export(shard_register_adapter)
export(shard_share_hook)
export(shard_unregister_adapter)
export(shards)
export(shards_list)
export(share)
export(share_open)
export(shared_advise)
export(shared_diagnostics)
export(shared_info)
export(shared_reset_diagnostics)
export(shared_segment)
export(shared_vector)
export(shared_view)
export(stream_count)
export(stream_filter)
export(stream_group_count)
export(stream_group_sum)
export(stream_map)
export(stream_reduce)
export(stream_sum)
export(stream_top_k)
export(string_col)
export(succeeded)
export(table_buffer)
export(table_diagnostics)
export(table_finalize)
export(table_sink)
export(table_write)
export(task_report)
export(view)
export(view_block)
export(view_diagnostics)
export(view_gather)
export(view_info)
useDynLib(shard, .registration = TRUE)
