% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{table_write.shard_table_sink}
\alias{table_write.shard_table_sink}
\title{Write a shard's row-group output}
\usage{
\method{table_write}{shard_table_sink}(target, rows_or_shard_id, data, ...)
}
\arguments{
\item{target}{A \code{shard_table_sink}.}

\item{rows_or_shard_id}{Integer shard id used to name the row-group file.}

\item{data}{A data.frame matching the sink schema.}

\item{...}{Reserved for future extensions.}
}
\value{
NULL (invisibly).
}
\description{
Write a shard's row-group output
}
