% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnostics.R
\name{print.shard_report}
\alias{print.shard_report}
\title{Print a shard_report Object}
\usage{
\method{print}{shard_report}(x, ...)
}
\arguments{
\item{x}{A \code{shard_report} object.}

\item{...}{Ignored.}
}
\value{
The input \code{x}, invisibly.
}
\description{
Print a shard_report Object
}
\examples{
\donttest{
res <- shard_map(shards(100, workers = 2), function(s) sum(s$idx), workers = 2)
pool_stop()
rpt <- report(result = res)
print(rpt)
}
}
