% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{table_diagnostics}
\alias{table_diagnostics}
\title{Table Diagnostics}
\usage{
table_diagnostics()
}
\value{
A list with \code{writes}, \code{rows}, and \code{bytes}.
}
\description{
Per-process counters for table writes (number of table_write calls, rows,
and bytes written). shard_map uses deltas of these counters to produce
run-level diagnostics in copy_report().
}
