% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{as_tibble}
\alias{as_tibble}
\title{Materialize a shard table handle as a data.frame/tibble}
\usage{
as_tibble(x, max_bytes = 256 * 1024^2, ...)
}
\arguments{
\item{x}{A shard table object.}

\item{max_bytes}{Warn if estimated payload exceeds this threshold.}

\item{...}{Reserved for future extensions.}
}
\value{
A data.frame (or tibble if the \code{tibble} package is installed).
}
\description{
Materialize a shard table handle as a data.frame/tibble
}
\examples{
\donttest{
s <- schema(x = float64(), y = int32())
tb <- table_buffer(s, nrow = 5L)
table_write(tb, idx_range(1, 5), data.frame(x = rnorm(5), y = 1:5))
df <- as_tibble(tb)
}
}
