% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{iterate_row_groups}
\alias{iterate_row_groups}
\title{Iterate row groups}
\usage{
iterate_row_groups(x, decode = TRUE)
}
\arguments{
\item{x}{A \code{shard_row_groups} handle.}

\item{decode}{Logical. If TRUE (default), native-encoded partitions are
decoded to data.frames. If FALSE, native partitions are returned as their
internal representation (advanced).}
}
\value{
A zero-argument iterator function that returns the next data.frame on
each call, or \code{NULL} when exhausted.
}
\description{
Iterate row groups
}
\examples{
\donttest{
s <- schema(x = float64())
sink <- table_sink(s, mode = "row_groups")
table_write(sink, 1L, data.frame(x = rnorm(5)))
rg <- table_finalize(sink)
it <- iterate_row_groups(rg)
chunk <- it()
}
}
