% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table_stream.R
\name{stream_count}
\alias{stream_count}
\title{Stream row count}
\usage{
stream_count(x)
}
\arguments{
\item{x}{A \code{shard_row_groups} or \code{shard_dataset} handle.}
}
\value{
A single integer giving the total number of rows across all partitions.
}
\description{
Stream row count
}
\examples{
\donttest{
s <- schema(x = float64())
sink <- table_sink(s, mode = "row_groups")
table_write(sink, 1L, data.frame(x = rnorm(5)))
rg <- table_finalize(sink)
stream_count(rg)
}
}
