% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{as_tibble.shard_table_buffer}
\alias{as_tibble.shard_table_buffer}
\title{Materialize a fixed table handle or buffer}
\usage{
\method{as_tibble}{shard_table_buffer}(x, max_bytes = 256 * 1024^2, ...)
}
\arguments{
\item{x}{A \code{shard_table_handle} or \code{shard_table_buffer}.}

\item{max_bytes}{Warn if estimated payload exceeds this threshold.}

\item{...}{Reserved for future extensions.}
}
\value{
A data.frame (or tibble).
}
\description{
Converts a \code{shard_table_handle} to an in-memory data.frame (or tibble if the
tibble package is installed).
}
