% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scratch.R
\name{scratch_pool_config}
\alias{scratch_pool_config}
\title{Configure scratch pool limits}
\usage{
scratch_pool_config(max_bytes = Inf)
}
\arguments{
\item{max_bytes}{Maximum scratch pool bytes allowed in a worker. If exceeded,
the worker is flagged for recycle at the next safe point.}
}
\value{
\code{NULL}, invisibly.
}
\description{
Configure scratch pool limits
}
\examples{
cfg <- scratch_pool_config(max_bytes = 100 * 1024^2)
}
