% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dispatch.R
\name{pool_lapply}
\alias{pool_lapply}
\title{Parallel Dispatch with Async Workers}
\usage{
pool_lapply(X, FUN, ..., pool = NULL, chunk_size = 1L)
}
\arguments{
\item{X}{List or vector to iterate over.}

\item{FUN}{Function to apply to each element.}

\item{...}{Additional arguments to FUN.}

\item{pool}{A \code{shard_pool} object. If NULL, uses current pool.}

\item{chunk_size}{Integer. Elements per chunk (default 1).}
}
\value{
A list of results.
}
\description{
An alternative dispatch that uses parallel::parLapply-style execution
but with supervision. This is a simpler interface for basic parallel apply.
}
\examples{
\donttest{
pool_create(2)
result <- pool_lapply(1:4, function(x) x^2, pool = pool_get())
pool_stop()
}
}
