% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/worker.R
\name{worker}
\alias{worker}
\title{Individual Worker Control}
\description{
Spawn, monitor, and control individual R worker processes.
}
