% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/buffer.R
\name{buffer_info}
\alias{buffer_info}
\title{Get Buffer Info}
\usage{
buffer_info(x)
}
\arguments{
\item{x}{A shard_buffer object.}
}
\value{
A named list with buffer properties: \code{type}, \code{dim},
\code{n}, \code{bytes}, \code{backing}, \code{path}, and \code{readonly}.
}
\description{
Returns information about a buffer.
}
\examples{
\donttest{
buf <- buffer("integer", dim = c(5, 5))
buffer_info(buf)
buffer_close(buf)
}
}
