% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pool.R
\name{pool_status}
\alias{pool_status}
\title{Get Pool Status}
\usage{
pool_status(pool = NULL)
}
\arguments{
\item{pool}{A \code{shard_pool} object. If NULL, uses the current pool.}
}
\value{
A data frame with worker status information.
}
\description{
Returns current status of all workers in the pool.
}
\examples{
\donttest{
p <- pool_create(2)
pool_status(p)
pool_stop(p)
}
}
