% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dispatch.R
\name{pool_sapply}
\alias{pool_sapply}
\title{Parallel sapply with Supervision}
\usage{
pool_sapply(X, FUN, ..., simplify = TRUE, pool = NULL)
}
\arguments{
\item{X}{List or vector to iterate over.}

\item{FUN}{Function to apply.}

\item{...}{Additional arguments to FUN.}

\item{simplify}{Logical. Simplify result to vector/matrix?}

\item{pool}{A \code{shard_pool} object. If NULL, uses current pool.}
}
\value{
Simplified result if possible, otherwise a list.
}
\description{
Parallel sapply with Supervision
}
\examples{
\donttest{
pool_create(2)
result <- pool_sapply(1:4, function(x) x^2, pool = pool_get())
pool_stop()
}
}
