% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/segment.R
\name{segment_info}
\alias{segment_info}
\title{Get segment information}
\usage{
segment_info(x)
}
\arguments{
\item{x}{A shard_segment object}
}
\value{
A named list with segment metadata including \code{size}, \code{backing},
\code{path}, \code{readonly}, and \code{owns}.
}
\description{
Get segment information
}
\examples{
\donttest{
seg <- segment_create(1024)
segment_info(seg)
segment_close(seg)
}
}
