% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/queue.R
\name{queue}
\alias{queue}
\title{Chunk Queue Management}
\description{
Queue management for dispatching chunks to workers with requeue support.
}
