% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{table_finalize.shard_table_buffer}
\alias{table_finalize.shard_table_buffer}
\title{Finalize a table buffer}
\usage{
\method{table_finalize}{shard_table_buffer}(
  target,
  materialize = c("never", "auto", "always"),
  max_bytes = 256 * 1024^2,
  ...
)
}
\arguments{
\item{target}{A \code{shard_table_buffer}.}

\item{materialize}{\code{"never"}, \code{"auto"}, or \code{"always"}.}

\item{max_bytes}{For \code{"auto"}, materialize only if estimated bytes <= max_bytes.}

\item{...}{Reserved for future extensions.}
}
\value{
A \code{shard_table_handle} or a materialized data.frame/tibble.
}
\description{
Finalize a table buffer
}
