% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{table_write.shard_table_buffer}
\alias{table_write.shard_table_buffer}
\title{Write into a table buffer}
\usage{
\method{table_write}{shard_table_buffer}(target, rows_or_shard_id, data, ...)
}
\arguments{
\item{target}{A \code{shard_table_buffer}.}

\item{rows_or_shard_id}{Row selector (idx_range or integer vector).}

\item{data}{A data.frame or named list matching the schema columns.}

\item{...}{Reserved for future extensions.}
}
\value{
NULL (invisibly).
}
\description{
Write into a table buffer
}
