% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dispatch.R
\name{print.shard_dispatch_result}
\alias{print.shard_dispatch_result}
\title{Print a shard_dispatch_result Object}
\usage{
\method{print}{shard_dispatch_result}(x, ...)
}
\arguments{
\item{x}{A \code{shard_dispatch_result} object.}

\item{...}{Further arguments (ignored).}
}
\value{
The input \code{x}, invisibly.
}
\description{
Print a shard_dispatch_result Object
}
\examples{
\donttest{
pool_create(2)
chunks <- list(list(id = 1L, x = 1), list(id = 2L, x = 2))
result <- dispatch_chunks(chunks, function(chunk) chunk$x, pool = pool_get())
print(result)
pool_stop()
}
}
