% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pool.R
\name{pool}
\alias{pool}
\title{Worker Pool Management}
\description{
Spawn and supervise persistent R worker processes with RSS monitoring.
}
