% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tables.R
\name{as_tibble.shard_row_groups}
\alias{as_tibble.shard_row_groups}
\title{Materialize a row-groups handle into a data.frame/tibble}
\usage{
\method{as_tibble}{shard_row_groups}(x, max_bytes = 256 * 1024^2, ...)
}
\arguments{
\item{x}{A \code{shard_row_groups} handle.}

\item{max_bytes}{Accepted for API consistency; currently unused for row-groups.}

\item{...}{Reserved for future extensions.}
}
\value{
A data.frame (or tibble if the \code{tibble} package is installed).
}
\description{
Materialize a row-groups handle into a data.frame/tibble
}
